@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.aws_cognito._jsii
 import aws_cdk.aws_dynamodb._jsii
@@ -17,7 +17,7 @@ import aws_cdk.core._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@aws-cdk/aws-appsync", "1.63.0", __name__[0:-6], "aws-appsync@1.63.0.jsii.tgz"
+    "@aws-cdk/aws-appsync", "1.65.0", __name__[0:-6], "aws-appsync@1.65.0.jsii.tgz"
 )
 
 __all__ = [
